Executor

Trait Executor 

pub trait Executor {
    // Required method
    fn join(self) -> Vec<Result<()>> ;
}
A trait representing a running executor

Required Methods

fn join(self) -> Vec<Result<()>>

Similar to the standard join, except that there can be several threads which must all return ().

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors